@@ -16,9 +16,16 @@ use vulkano::{
     command_buffer::{AutoCommandBufferBuilder, CommandBufferUsage, SubpassContents},
     device::{physical::PhysicalDevice, Device, DeviceExtensions, Features, Queue},
     format::Format,
-    image::{view::ImageView, ImageUsage, SwapchainImage},
+    image::{view::ImageView, ImageAccess, ImageUsage, SwapchainImage},
     instance::{Instance, InstanceExtensions},
-    pipeline::{viewport::Viewport, GraphicsPipeline},
+    pipeline::{
+        graphics::{
+            input_assembly::InputAssemblyState,
+            vertex_input::BuffersDefinition,
+            viewport::{Viewport, ViewportState},
+        },
+        GraphicsPipeline,
+    },
     render_pass::{Framebuffer, RenderPass, Subpass},
     swapchain,
     swapchain::{
@@ -120,7 +127,7 @@ struct SimpleGuiRenderer {
     render_pass: Arc<RenderPass>,
     pipeline: Arc<GraphicsPipeline>,
     swap_chain: Arc<Swapchain<Window>>,
-    final_images: Vec<Arc<ImageView<Arc<SwapchainImage<Window>>>>>,
+    final_images: Vec<Arc<ImageView<SwapchainImage<Window>>>>,
     recreate_swapchain: bool,
     previous_frame_end: Option<Box<dyn GpuFuture>>,
     vertex_buffer: Arc<CpuAccessibleBuffer<[Vertex]>>,
@@ -236,7 +243,7 @@ impl SimpleGuiRenderer {
         device: Arc<Device>,
         queue: Arc<Queue>,
         present_mode: PresentMode,
-    ) -> (Arc<Swapchain<Window>>, Vec<Arc<ImageView<Arc<SwapchainImage<Window>>>>>) {
+    ) -> (Arc<Swapchain<Window>>, Vec<Arc<ImageView<SwapchainImage<Window>>>>) {
         let caps = surface.capabilities(physical).unwrap();
         let alpha = caps.supported_composite_alpha.iter().next().unwrap();
         let format = caps.supported_formats[0].0;
@@ -262,24 +269,22 @@ impl SimpleGuiRenderer {
     }
 
     fn create_render_pass(device: Arc<Device>, format: Format) -> Arc<RenderPass> {
-        Arc::new(
-            vulkano::ordered_passes_renderpass!(
-                device,
-                attachments: {
-                    color: {
-                        load: Clear,
-                        store: Store,
-                        format: format,
-                        samples: 1,
-                    }
-                },
-                passes: [
-                    { color: [color], depth_stencil: {}, input: [] }, // Draw what you want on this pass
-                    { color: [color], depth_stencil: {}, input: [] } // Gui render pass
-                ]
-            )
-            .unwrap(),
+        vulkano::ordered_passes_renderpass!(
+            device,
+            attachments: {
+                color: {
+                    load: Clear,
+                    store: Store,
+                    format: format,
+                    samples: 1,
+                }
+            },
+            passes: [
+                { color: [color], depth_stencil: {}, input: [] }, // Draw what you want on this pass
+                { color: [color], depth_stencil: {}, input: [] } // Gui render pass
+            ]
         )
+        .unwrap()
     }
 
     fn gui_pass(&self) -> Subpass {
@@ -287,20 +292,18 @@ impl SimpleGuiRenderer {
     }
 
     fn create_pipeline(device: Arc<Device>, render_pass: Arc<RenderPass>) -> Arc<GraphicsPipeline> {
-        let vs = vs::Shader::load(device.clone()).expect("failed to create shader module");
-        let fs = fs::Shader::load(device.clone()).expect("failed to create shader module");
+        let vs = vs::load(device.clone()).expect("failed to create shader module");
+        let fs = fs::load(device.clone()).expect("failed to create shader module");
 
-        Arc::new(
-            GraphicsPipeline::start()
-                .vertex_input_single_buffer::<Vertex>()
-                .vertex_shader(vs.main_entry_point(), ())
-                .triangle_list()
-                .viewports_dynamic_scissors_irrelevant(1)
-                .fragment_shader(fs.main_entry_point(), ())
-                .render_pass(Subpass::from(render_pass, 0).unwrap())
-                .build(device)
-                .unwrap(),
-        )
+        GraphicsPipeline::start()
+            .vertex_input_state(BuffersDefinition::new().vertex::<Vertex>())
+            .vertex_shader(vs.entry_point("main").unwrap(), ())
+            .input_assembly_state(InputAssemblyState::new())
+            .fragment_shader(fs.entry_point("main").unwrap(), ())
+            .viewport_state(ViewportState::viewport_dynamic_scissor_irrelevant())
+            .render_pass(Subpass::from(render_pass, 0).unwrap())
+            .build(device)
+            .unwrap()
     }
 
     pub fn queue(&self) -> Arc<Queue> {
@@ -341,14 +344,12 @@ impl SimpleGuiRenderer {
         )
         .unwrap();
 
-        let dimensions = self.final_images[0].image().dimensions();
-        let framebuffer = Arc::new(
-            Framebuffer::start(self.render_pass.clone())
-                .add(self.final_images[image_num].clone())
-                .unwrap()
-                .build()
-                .unwrap(),
-        );
+        let dimensions = self.final_images[0].image().dimensions().width_height();
+        let framebuffer = Framebuffer::start(self.render_pass.clone())
+            .add(self.final_images[image_num].clone())
+            .unwrap()
+            .build()
+            .unwrap();
 
         // Begin render pipeline commands
         let clear_values = vec![[0.0, 1.0, 0.0, 1.0].into()];
